@@ -34,11 +34,11 @@ BEGIN { eval { require warnings } && warnings->unimport ("uninitialized") }
 
 use Coro ();
 
-$VERSION = 1.11;
+$VERSION = 1.3;
 
 =item new [inital count]
 
-Creates a new sempahore set with the given initial lock count for each
+Creates a new semaphore set with the given initial lock count for each
 individual semaphore. See L<Coro::Semaphore>.
 
 =cut
@@ -47,12 +47,12 @@ sub new {
    bless [defined $_[1] ? $_[1] : 1], $_[0];
 }
 
-=item $sem->down($id)
+=item $sem->down ($id)
 
 Decrement the counter, therefore "locking" the named semaphore. This
 method waits until the semaphore is available if the counter is zero.
 
-=item $status = $sem->timed_down($id, $timeout)
+=item $status = $sem->timed_down ($id, $timeout)
 
 Like C<down>, but returns false if semaphore couldn't be acquired within
 $timeout seconds, otherwise true.
@@ -60,38 +60,48 @@ $timeout seconds, otherwise true.
 =cut
 
 sub down {
-   my $sem = ($_[0][1]{$_[1]} ||= [$_[0][0]]);
-   while ($sem->[0] <= 0) {
+   while () {
+      my $sem = ($_[0][1]{$_[1]} ||= [$_[0][0]]);
+
+      if ($sem->[0] > 0) {
+         --$sem->[0];
+         return 1;
+      }
+
       push @{$sem->[1]}, $Coro::current;
       Coro::schedule;
    }
-   --$sem->[0];
 }
 
 sub timed_down {
    require Coro::Timer;
-   my $timeout = Coro::Timer::timeout($_[2]);
+   my $timeout = Coro::Timer::timeout ($_[2]);
+
+   while () {
+      my $sem = ($_[0][1]{$_[1]} ||= [$_[0][0]]);
+
+      if ($sem->[0] > 0) {
+         --$sem->[0];
+         return 1;
+      }
 
-   my $sem = ($_[0][1]{$_[1]} ||= [$_[0][0]]);
-   while ($sem->[0] <= 0) {
-      push @{$sem->[1]}, $Coro::current;
-      Coro::schedule;
       if ($timeout) {
          # ugly as hell.
          for (0..$#{$sem->[1]}) {
             if ($sem->[1][$_] == $Coro::current) {
                splice @{$sem->[1]}, $_, 1;
-               return;
+               return 0;
             }
          }
          die;
       }
+
+      push @{$sem->[1]}, $Coro::current;
+      Coro::schedule;
    }
-   --$sem->[0];
-   return 1;
 }
 
-=item $sem->up($id)
+=item $sem->up ($id)
 
 Unlock the semaphore again.
 
@@ -99,10 +109,12 @@ Unlock the semaphore again.
 
 sub up {
    my $sem = $_[0][1]{$_[1]};
+
    if (++$sem->[0] > 0) {
       (shift @{$sem->[1]})->ready if @{$sem->[1]};
    }
-   delete $_[0][1]{$_[1]} if $sem->[0] == $_[0][0];
+
+   delete $_[0][1]{$_[1]} if $sem->[0] == $_[0][0] && !@{$sem->[1] || []};
 }
 
 =item $sem->try
@@ -122,7 +134,7 @@ sub try {
    }
 }
 
-=item $sem->waiters($id)
+=item $sem->waiters ($id)
 
 In scalar context, returns the number of coroutines waiting for this
 semaphore.
@@ -130,15 +142,17 @@ semaphore.
 =cut
 
 sub waiters {
-   @{$_[0][1]{$_[1]}};
+   my $sem = $_[0][1]{$_[1]}
+      or return;
+   @{ $_[0][1]{$_[1]}[1] || []}
 }
 
-=item $guard = $sem->guard($id)
+=item $guard = $sem->guard ($id)
 
 This method calls C<down> and then creates a guard object. When the guard
 object is destroyed it automatically calls C<up>.
 
-=item $guard = $sem->timed_guard($id, $timeout)
+=item $guard = $sem->timed_guard ($id, $timeout)
 
 Like C<guard>, but returns undef if semaphore couldn't be acquired within
 $timeout seconds, otherwise the guard object.
